# unitorch.cli.datasets.hf

## ASTDatasets

!!! tip
    **`core/dataset/ast`** is the section for configuration of ASTDatasets.

::: unitorch.cli.datasets.hf.ASTDatasets.__getdataset__

!!! tip
    **`core/dataset/ast/train`** is the section for configuration of ASTDatasets Training Data.
    
!!! tip
    **`core/dataset/ast/dev`** is the section for configuration of ASTDatasets Validation Data.
    
!!! tip
    **`core/dataset/ast/test`** is the section for configuration of ASTDatasets Test Data.

